package com.backendsys.service.B2c;

import com.backendsys.entity.B2c.B2cGoodSpecSkuDTO;

import java.util.List;
import java.util.Map;

public interface B2cGoodSpecSkuService {
    Map<String, Object> queryGoodSpecSkuList(Integer pageNum, Integer pageSize, B2cGoodSpecSkuDTO b2cGoodSpecSkuDTO);
    List<Map<String, Object>> queryGoodSpecSkuBatch(Long[] sku_ids);
    Map<String, Object> queryGoodSpecSkuDetail(Long good_id);
    Map<String, Object> insertGoodSpecSku(B2cGoodSpecSkuDTO b2cGoodSpecSkuDTO);
    Map<String, Object> updateGoodSpecSku(B2cGoodSpecSkuDTO b2cGoodSpecSkuDTO);
    Map<String, Object> deleteGoodSpecSku(B2cGoodSpecSkuDTO b2cGoodSpecSkuDTO);
}
